/*
 *  This sketch demonstrates how to set up a simple HTTP-like server.
 *  The server will set a GPIO pin depending on the request
 *    http://server_ip/gpi2/0 will set the GPIO2 low,
 *    http://server_ip/gpi3/1 will set the GPIO3 high
 *  server_ip is the IP address of the ESP8266 module, will be 
 *  printed to Serial when the module is connected.
 */

#include <ESP8266WiFi.h>

// the IP address for the module:
//IPAddress ip(192, 168, 0, 177);    
const char* ssid = "ASUS";
const char* password = "SVETA000";

int pin2 = 2;  //GPIO2        
int pin3 = 3;  //RxD  GPIO3   

  int val2 = 0;
  int val3 = 0;

// Create an instance of the server
// specify the port to listen on as an argument
WiFiServer server(80);

void setup() {
//  Serial.begin(115200);
  delay(10);

  // prepare GPIO2
  pinMode(pin2, OUTPUT);
  digitalWrite(pin2, val2);
  pinMode(pin3, OUTPUT);
  digitalWrite(pin3, val3);
  
  // Connect to WiFi network
//  Serial.println();
//  Serial.println();
//  Serial.print("Connecting to ");
//  Serial.println(ssid);
  
//  WiFi.config(ip);
  WiFi.begin(ssid, password);
  
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
//    Serial.print(".");
  }
//  Serial.println("");
//  Serial.println("WiFi connected");
  
  // Start the server
  server.begin();
//  Serial.println("Server started");

  // Print the IP address
//  Serial.println(WiFi.localIP());
  digitalWrite(pin2, 1);  //для контроля включения web-сервера
}

void loop() {
  // Check if a client has connected
  WiFiClient client = server.available();
  if (!client) {
    return;
  }
  
  // Wait until the client sends some data
//  Serial.println("new client");
  while(!client.available()){
    delay(1);
  }
  
  // Read the first line of the request
  String req = client.readStringUntil('\r');
//  Serial.println(req);
  client.flush();
  
  // Match the request
  if (req.indexOf("/gpio2/0") != -1)
    val2 = 0;
  else if (req.indexOf("/gpio2/1") != -1)
    val2 = 1;
  else if (req.indexOf("/gpio3/0") != -1)
    val3 = 0;
  else if (req.indexOf("/gpio3/1") != -1)
    val3 = 1;
  else {
//    Serial.println("invalid request");
    client.stop();
    return;
  }

  // Set GPIO2, GPIO3  according to the request
  digitalWrite(pin2, val2);
  digitalWrite(pin3, val3);
  
  client.flush();

  // Prepare the response
  String s = "HTTP/1.1 200 OK\r\nContent-Type: text/html\r\n\r\n<!DOCTYPE HTML>\r\n<html>\r\nGPIO (2,3) is now ";
  s += (val2)?"high, ":"low, ";
  s += (val3)?"high, ":"low, ";
  s += "</html>\n";

  // Send the response to the client
  client.print(s);
  delay(1);
//  Serial.println("Client disonnected");

  // The client will actually be disconnected 
  // when the function returns and 'client' object is detroyed
}

